@@ -6,6 +6,7 @@ from AccessControl import ClassSecurityInfo
 from Products.Archetypes.atapi import *
 from Products.CMFCore import permissions
 from Products.CMFCore.utils import UniqueObject, getToolByName 
+from Products.statusmessages.interfaces import IStatusMessage
 
 from Products.ATContentTypes.content.document import ATDocument
 from Products.ATContentTypes.content.event import ATEvent
@@ -60,9 +61,9 @@ class Parser(object):
         err_results = []
         for err in errors:
             diz = {}
-            diz['m:line'] = int(err.getElementsByTagName('m:line')[0].childNodes[0].nodeValue)
+            diz['m:line'] = err.getElementsByTagName('m:line')[0].childNodes[0].nodeValue
             diz['m:message'] = err.getElementsByTagName('m:message')[0].childNodes[0].nodeValue
-            diz['m:col'] = int(err.getElementsByTagName('m:col')[0].childNodes[0].nodeValue)
+            diz['m:col'] = err.getElementsByTagName('m:col')[0].childNodes[0].nodeValue
             err_results.append(diz)
         errs = results['m:errors']
         errs['m:errorcount'] = len(err_results)
@@ -73,14 +74,15 @@ class Parser(object):
         warn_results = []
         for warn in warnings:
             diz = {}
-            try:
-                diz['m:line'] = int(warn.getElementsByTagName('m:line')[0].childNodes[0].nodeValue)
-                diz['m:col'] = int(warn.getElementsByTagName('m:col')[0].childNodes[0].nodeValue)
-            except IndexError:
-                diz['m:line'] = 0
-                diz['m:col'] = 0
-            diz['m:message'] = warn.getElementsByTagName('m:message')[0].childNodes[0].nodeValue
-            warn_results.append(diz)   
+            if warn.getElementsByTagName('m:message')[0].childNodes[0].nodeValue != 'DOCTYPE Override in effect!':
+                try:
+                    diz['m:line'] = warn.getElementsByTagName('m:line')[0].childNodes[0].nodeValue
+                    diz['m:col'] = warn.getElementsByTagName('m:col')[0].childNodes[0].nodeValue
+                except IndexError:
+                    diz['m:line'] = 0
+                    diz['m:col'] = 0
+                diz['m:message'] = warn.getElementsByTagName('m:message')[0].childNodes[0].nodeValue
+                warn_results.append(diz)   
         warns = results['m:warnings']
         warns['m:warningcount'] = len(warn_results)
         warns['m:warninglist'] = warn_results
@@ -161,36 +163,81 @@ class Parser(object):
 
     security.declarePrivate('createReportDocument')
     def createReportDocument(self,fileout,toterr,totwarn,tot_files,valid):
-        # Save report in the tool as ATReport
-        newId = self.context.generateUniqueId('report')
         now = DateTime().strftime("%d/%m/%Y")
-        title="Report %s: %s" % (self.val_type,now)
         container = self.context
-        type_name = "ATReport"
+        portal_transforms = getToolByName(self.context, 'portal_transforms')
         pt = getToolByName(self.context, 'portal_types')
-        info = pt.getTypeInfo( type_name )
-        ob = info._constructInstance(container, newId)
-        ob.setTitle(title)
-        ob.setDescription(self.createDescription(toterr,totwarn,tot_files))
-        ob.setText(fileout)
-        ob.setIs_valid(valid)
-        info._finishConstruction(ob)
+        
+        if self.context.getCreateReport():
+            # Save report in the tool as ATReport
+            
+            newId = self.context.generateUniqueId('report')
+            title="Report %s: %s" % (self.val_type,now)
+            type_name = "ATReport"
+            info = pt.getTypeInfo( type_name )
+            ob = info._constructInstance(container, newId)
+            ob.setTitle(title)
+            ob.setDescription(self.createDescription(toterr,totwarn,tot_files))
+            ob.setText(fileout)
+            ob.setIs_valid(valid)
+            info._finishConstruction(ob)
+            
+        elif self.context.getCreateReportText():
+            #create a text report
+            newId = self.context.generateUniqueId('report-text')
+            type_name = "ATFileReport"
+            title="Report Text %s: %s" % (self.val_type,now)
+            info = pt.getTypeInfo( type_name )
+            ob = info._constructInstance(container, newId)
+            file_title = 'report_text_'+DateTime().strftime("%d-%m-%Y")
+            ob.setTitle(title)
+            ob.setDescription(self.createDescription(toterr,totwarn,tot_files))
+            ob.setFile(portal_transforms.convert('html_to_web_intelligent_plain_text',fileout).getData())
+            ob.setFilename(file_title+'.txt')
+            ob.setContentType('text/plain')
+            ob.setIs_valid(valid)
+            info._finishConstruction(ob)
         
         return newId
 
     security.declarePrivate('createDebugReportDocument')
     def createDebugReportDocument(self,fileout,toterr,totwarn,tot_files,valid):
         # Save report in the tool as ATReport
-        newId = self.context.generateUniqueId('report')
-        self.context.invokeFactory(id=newId, type_name='ATReport',language='')
         now = DateTime().strftime("%d/%m/%Y")
-        f = getattr(self.context, newId)
-        f.edit(title="Report %s Content Type: %s" %(self.val_type,now),
-               #description="%s errors, %s warnings in %s file(s)" % (toterr, totwarn, tot_files),
-               description = self.createDescription(toterr,totwarn,tot_files),
-               text=fileout,
-               is_valid=valid,
-              )
+        container = self.context
+        portal_transforms = getToolByName(self.context, 'portal_transforms')
+        pt = getToolByName(self.context, 'portal_types')
+        
+        if self.context.getCreateReport():
+            # Save report in the tool as ATReport
+            
+            newId = self.context.generateUniqueId('report')
+            title="Report Debug %s: %s" % (self.val_type,now)
+            type_name = "ATReport"
+            info = pt.getTypeInfo( type_name )
+            ob = info._constructInstance(container, newId)
+            ob.setTitle(title)
+            ob.setDescription(self.createDescription(toterr,totwarn,tot_files))
+            ob.setText(fileout)
+            ob.setIs_valid(valid)
+            info._finishConstruction(ob)
+            
+        elif self.context.getCreateReportText():
+            #create a text report
+            newId = self.context.generateUniqueId('report-text')
+            type_name = "ATFileReport"
+            title="Report Debug Text %s: %s" % (self.val_type,now)
+            info = pt.getTypeInfo( type_name )
+            ob = info._constructInstance(container, newId)
+            file_title = 'report_debug_text_'+DateTime().strftime("%d-%m-%Y")
+            ob.setTitle(title)
+            ob.setDescription(self.createDescription(toterr,totwarn,tot_files))
+            ob.setFile(portal_transforms.convert('html_to_web_intelligent_plain_text',fileout).getData())
+            ob.setFilename(file_title+'.txt')
+            ob.setContentType('text/plain')
+            ob.setIs_valid(valid)
+            info._finishConstruction(ob)
+            
         return newId
 
     security.declarePrivate('createDescription')
@@ -277,6 +324,8 @@ class Parser(object):
     security.declarePrivate('sendReportAsAttach')
     def sendReportAsAttach(self,str_report,filenamepars, send_from=None, send_to=[], subject="", text="", files=[]):
         """Send the content of a file as attachment to adresses list"""
+        plone_utils = self.context.plone_utils
+        
         tempf = tempfile.NamedTemporaryFile()
         tempf.write(str_report)
         tempf.flush()
@@ -300,8 +349,9 @@ class Parser(object):
         text = text or text1
         files = [tempf.name,]
         server = self.context.MailHost.smtp_host
-
-        sendattachment.send_mail(send_from=send_from,
+        
+        try:
+            sendattachment.send_mail(send_from=send_from,
                                  send_to=send_to,
                                  subject=subject,
                                  text=text,
@@ -310,4 +360,13 @@ class Parser(object):
                                  mimeb=("text", "html"),
                                  filenamepars=filenamepars,
                                  )
+            text=self.translation_service.utranslate(domain='collective.validator.base',
+                                                    msgid='mail_sent_message',
+                                                    default="Mail sent",
+                                                    context=self.context)
+            
+            plone_utils.addPortalMessage(text)
+        except Exception, err:
+            plone_utils.addPortalMessage(err)
+            
         tempf.close()
