@@ -4,17 +4,16 @@ from Products.Five import BrowserView
 
 
 class RemoteValidation(BrowserView):
-    """vista per fare l'aggiornamento di TagCloud"""
+    """vista per fare la validaizone del sito"""
 
     def remoteValidation(self):
         """
         @author: andrea cecchi
-        Metodo che richiamato aggiorna TagCloud
+        Metodo che richiamato esegue la validazione del sito
         """
-        self.context.plone_log('INIZIOOOOO')
-#        xhtml= self.context.view().encode('utf-8')
+        self.context.plone_log('Inizio validazione')
         p_ist= self.context.portal_validationtool
         results=p_ist.runVal()
-        self.context.plone_log('VALIDAIZONE ESEGUITA')
+        self.context.plone_log('Validazione eseguita')
 
         
